@@ -6,6 +6,7 @@ Base class for other runners
 """
 
 import tempfile
+import logging
 from ...engine import exec_exp_commands
 
 
@@ -19,12 +20,22 @@ class Runner:
         temporary file to hold the stats
     err : File
         temporary file to hold any errors
+    start_time : num
+            time at which netperf is to run
+    run_time : num
+        total time to run netperf for
     """
 
-    def __init__(self):
+    def __init__(self, start_time, run_time):
         self.out = tempfile.TemporaryFile()
         self.err = tempfile.TemporaryFile()
 
+        self.logger = logging.getLogger(__name__)
+        self.logger.setLevel(logging.INFO)
+
+        self.start_time = start_time
+        self.run_time = run_time
+
     def run(self, command):
         """
         Runs the `command` and stores stdout or stderr
@@ -39,7 +50,19 @@ class Runner:
         Method to print error from `self.err`.
         Should be overriden by base class
         """
-        print('Unknown error occured')
+        self.logger.error('Unknown error occured')
+
+    def get_meta_item(self):
+        """
+        Return the meta item for the given flow.
+        This "meta" information is required by plotter.
+        """
+        meta_item = {
+            'meta': True,
+            'start_time': str(self.start_time),
+            'stop_time': str(self.start_time + self.run_time)
+        }
+        return meta_item
 
     def clean_up(self):
         """
